@@ -8,6 +8,10 @@ from .enums import BrowserInteraction, BrowserAction
 from .utils import _parse_action_response, center_bbox
 from .browserActor import BrowserActor
 
+# BASE_URL = "https://u3mvtbirxf.us-east-1.awsapprunner.com"
+
+
+# dev: 
 BASE_URL = "https://vytaq823ad.us-east-1.awsapprunner.com"
 
 class Simplex:
@@ -42,7 +46,7 @@ class Simplex:
         self.timeout = timeout
         self.max_retries = max_retries
 
-        self.browser_actor = BrowserActor(record_video)
+        self.browser_actor = BrowserActor(record_video=record_video)
 
     def find_element(
         self,
